==> haskell-skylighting-format-ansi-0.1-181-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-HhXVWqRRcMj3tg38ZPV0uV
key:                  skylighting-format-ansi-0.1-HhXVWqRRcMj3tg38ZPV0uV
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  c01036c40fd5e63ef7e2805baedc8756
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-HhXVWqRRcMj3tg38ZPV0uV
depends:
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb containers-0.6.7
    skylighting-core-0.14.1.1-3WHlbGokXIbDaITT0sp4Uo text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-8HiqS1Es1Dz4VcOQaHr429
key:                  skylighting-format-ansi-0.1-8HiqS1Es1Dz4VcOQaHr429
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  906dac854886636e03997a27e3d75993
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-8HiqS1Es1Dz4VcOQaHr429
depends:
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb containers-0.6.7
    skylighting-core-0.14.1.1-9XqERILCLLJ2gPMYEnaxnX text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
